@@ -32,5 +32,5 @@ module.exports = [
   ['1.2.3-a.b', '1.2.3-a'],
   ['1.2.3-a.b.c.10.d.5', '1.2.3-a.b.c.5.d.100'],
   ['1.2.3-r2', '1.2.3-r100'],
-  ['1.2.3-r100', '1.2.3-R2']
+  ['1.2.3-r100', '1.2.3-R2'],
 ]
