@@ -48,8 +48,6 @@ module.exports = [
   ['1.2.*', '1.2.3'],
   ['1.2.* || 2.*', '2.1.3'],
   ['1.2.* || 2.*', '1.2.3'],
-  ['1.2.* || 2.*', '1.2.3'],
-  ['*', '1.2.3'],
   ['2', '2.1.2'],
   ['2.3', '2.3.1'],
   ['~2.4', '2.4.0'], // >=2.4.0 <2.5.0
@@ -85,5 +83,5 @@ module.exports = [
   ['^1.0.0-alpha', '1.0.0-beta'],
   ['~1.0.0-alpha', '1.0.0-beta'],
   ['=0.1.0', '1.0.0'],
-  ['>1.2.3', '1.3.0-alpha', { includePrerelease: true }]
+  ['>1.2.3', '1.3.0-alpha', { includePrerelease: true }],
 ]
